import { __decorate, __metadata } from "tslib";
import { Inject, Injectable, Logger, } from '@nestjs/common';
import { ClientProxy, } from '@nestjs/microservices';
import { randomBytes } from 'crypto';
import { SocketIoClientProvider } from './socket-io-client.provider';
export let SocketIoClientProxyService = class SocketIoClientProxyService extends ClientProxy {
    async connect() {
        this.client.getSocket();
        this.logger.debug('connect client proxy', 'SocketIoClientProxyService');
    }
    async close() {
        this.client.getSocket().disconnect();
        this.logger.debug('connect client proxy', 'SocketIoClientProxyService');
    }
    /**
     * this method use when you use SocketIoClientProxyService.emit
     * @param packet
     * @returns
     */
    async dispatchEvent(packet) {
        this.client.getSocket().emit(packet.pattern, packet.data);
        return;
    }
    /**
     * this method will be call when use SocketIoClientProxyService.send
     * can be use to implement request-response
     * @param packet
     * @param callback
     * @returns
     */
    publish(packet, callback) {
        this.logger.debug(`publish to pattern '${packet.pattern}'`, 'SocketIoClientProxyService');
        this.logger.verbose(`with data: ` + JSON.stringify(packet.data, undefined, 2), 'SocketIoClientProxyService');
        const event = randomBytes(64).toString('hex');
        const socket = this.client.getSocket().on(event, (data) => {
            callback({ response: data });
        });
        this.client.getSocket()
            .emit(packet.pattern, {
            data: packet.data,
            event,
        });
        return () => socket.off(event, () => {
            this.logger.log('socket off', 'SocketIoClientProxyService');
        });
    }
};
__decorate([
    Inject(Logger),
    __metadata("design:type", Logger)
], SocketIoClientProxyService.prototype, "logger", void 0);
__decorate([
    Inject(SocketIoClientProvider),
    __metadata("design:type", SocketIoClientProvider)
], SocketIoClientProxyService.prototype, "client", void 0);
SocketIoClientProxyService = __decorate([
    Injectable()
], SocketIoClientProxyService);
//# sourceMappingURL=socket-io-client-proxy.service.js.map