import { __decorate, __metadata } from "tslib";
import { Inject, Injectable, Logger, } from '@nestjs/common';
import { ConfigService } from '@nestjs/config';
import { BehaviorSubject, Subject, } from 'rxjs';
import { io, } from 'socket.io-client';
export var DisconnectReason;
(function (DisconnectReason) {
    /**
     * The server has forcefully disconnected the socket with socket.disconnect()
     */
    DisconnectReason["IO_SERVER_DISCONNECT"] = "io server disconnect";
    /**
     * The socket was manually disconnected using socket.disconnect()
     */
    DisconnectReason["IO_CLIENT_DISCONNECT"] = "io client disconnect";
    /**
     * The server did not send a PING within the pingInterval + pingTimeout range
     */
    DisconnectReason["PING_TIMEOUT"] = "ping timeout";
    /**
     * The connection was closed (example: the user has lost connection, or the network was changed from WiFi to 4G)
     */
    DisconnectReason["TRANSPORT_CLOSE"] = "transport close";
    /**
     * The connection has encountered an error (example: the server was killed during a HTTP long-polling cycle)
     */
    DisconnectReason["TRANSPORT_ERROR"] = "transport error";
})(DisconnectReason || (DisconnectReason = {}));
export let SocketIoClientProvider = class SocketIoClientProvider {
    constructor() {
        this.disconnected$ = new Subject();
        this.connected$ = new Subject();
        this.isConnected$ = new BehaviorSubject(false);
        this.getSocket = () => {
            if (!this.socket) {
                return this.connect();
            }
            return this.socket;
        };
    }
    connect() {
        this.socket = io(this.config.getOrThrow('COORDINATOR_SOCKET'), {
            transportOptions: {
                polling: {
                    extraHeaders: {
                        Authorization: `Bearer ${this.config.getOrThrow('COORDINATOR_JWT')}`,
                    },
                },
            },
        });
        this.socket.on('disconnect', (reason) => {
            this.logger.error('Socket is disconnected', 'SocketIoClientProvider');
            this.disconnected$.next(reason);
            this.isConnected$.next(false);
            if (reason == DisconnectReason.IO_SERVER_DISCONNECT) {
                this.logger.error('Server closed the connection. Try to reconnect', 'SocketIoClientProvider');
                this.socket?.connect();
            }
        });
        this.socket.on('connect', () => {
            this.logger.log('Socket is connected', 'SocketIoClientProvider');
            this.connected$.next();
            this.isConnected$.next(true);
        });
        this.socket.on('connect_error', () => {
            this.logger.error('Connection error', 'SocketIoClientProvider');
        });
        return this.socket;
    }
};
__decorate([
    Inject(Logger),
    __metadata("design:type", Logger)
], SocketIoClientProvider.prototype, "logger", void 0);
__decorate([
    Inject(ConfigService),
    __metadata("design:type", ConfigService)
], SocketIoClientProvider.prototype, "config", void 0);
SocketIoClientProvider = __decorate([
    Injectable()
], SocketIoClientProvider);
//# sourceMappingURL=socket-io-client.provider.js.map